@@ -24,13 +24,11 @@ class Config:
         return self.data.__getitem__(item)
 
     def dump(self):
-        self.path.write_text(yaml.dump(self.data, Dumper=yaml.SafeDumper))
+        Config.path.write_text(yaml.dump(self.data, Dumper=yaml.SafeDumper))
 
     @classmethod
     def reset(cls):
-        cls.path.write_text(
-            cls.default_path.read_text()
-        )
+        cls.path.write_text(cls.default_path.read_text())
 
 
 config = Config()
